@@ -2,7 +2,7 @@
 
 ###
 #
-# $Id: reptile-startup.sh,v 1.6 2001/08/01 17:17:51 burton Exp $
+# $Id: reptile-startup.sh,v 1.7 2001/09/20 23:39:42 burton Exp $
 #
 # Commentary:
 #
@@ -16,11 +16,3 @@ java -classpath $TOMCAT_HOME/lib/ant.jar:$TOMCAT_HOME/lib/xerces.jar \
      -Dtomcat.home=$TOMCAT_HOME org.apache.tools.ant.Main \
      -Dlog4j.debug=true \
      -emacs -file $TOMCAT_HOME/reptile.xml startup 
-
-
-#launch a web browser if necessary.  This is a developer feature.
-if [ "$REPTILE_LAUNCH_BROWER" != "" ]; then 
-
-    eval $$REPTILE_LAUNCH_BROWER
-
-fi
